@@ -1,16 +1,21 @@
+from typing import TYPE_CHECKING
+
 from .command import Command
 from .fields import (
     Enum as EnumField, Int, Bool, Str, StrCoded,
     Time12H, Time, DateTime, Bitmask, IPAddress, VideoWallModel)
 
 
-try:
+if TYPE_CHECKING:
     from enum import IntEnum
-except ImportError:
-    from enum import Enum
+else:
+    try:
+        from enum import IntEnum
+    except ImportError:
+        from enum import Enum
 
-    class IntEnum(int, Enum):
-        ...
+        class IntEnum(int, Enum):
+            ...
 
 
 class _COMMON:
@@ -1301,6 +1306,20 @@ class PANEL(Command):
     DATA = [PANEL_STATE]
 
 
+class SCREEN_MUTE(Command):
+    # Undocumented (as of Ver. 15 2020-11-06)
+    # see https://github.com/vgavro/samsung-mdc/issues/19
+    CMD = 0xFE
+    SUBCMD = 0x51
+    GET, SET = True, True
+
+    class SCREEN_MUTE_STATUS(IntEnum):
+        ON = 0x00
+        OFF = 0xFF
+
+    DATA = [SCREEN_MUTE_STATUS]
+
+
 class STATUS(Command):
     """
     Get the device various state like power, volume, sound mute, input source,
